Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1794)

Unified Diff: third_party/WebKit/public/platform/WebURLRequest.h

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: fix ContentResourceProviderTest Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/platform/network/ResourceRequest.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/platform/WebURLRequest.h
diff --git a/third_party/WebKit/public/platform/WebURLRequest.h b/third_party/WebKit/public/platform/WebURLRequest.h
index c58a4e491222d25c0643a790d77ce7e836e6c9af..b8a3ea4b4804fa2aa294c557cb0686b13a66ed7e 100644
--- a/third_party/WebKit/public/platform/WebURLRequest.h
+++ b/third_party/WebKit/public/platform/WebURLRequest.h
@@ -136,13 +136,18 @@ class WebURLRequest {
ReportIntent, // Report metrics with UI action displayed intent.
};
- // The LoFi state which determines whether to request a Lo-Fi version of the
- // resource.
- enum LoFiState {
- LoFiUnspecified, // Let the browser process decide whether or not to
- // request the Lo-Fi version.
- LoFiOff, // Request a normal (non-Lo-Fi) version of the resource.
- LoFiOn, // Request a Lo-Fi version of the resource.
+ // The Previews state which determines whether to request a Preview version of
+ // the resource.
+ enum PreviewsState {
+ PreviewsUnspecified = 0, // Let the browser process decide whether or
+ // not to request Preview types.
+ ServerLoFiOn = 1 << 0, // Request a Lo-Fi version of the resource
+ // from the server.
+ ClientLoFiOn = 1 << 1, // Request a Lo-Fi version of the resource
+ // from the client.
+ PreviewsOff = 1 << 2, // Request a normal (non-Preview) version of
+ // the resource.
+ PreviewsStateLast = PreviewsOff
};
// Indicates which types of ServiceWorkers should skip handling this request.
@@ -285,10 +290,11 @@ class WebURLRequest {
BLINK_PLATFORM_EXPORT FetchRedirectMode getFetchRedirectMode() const;
BLINK_PLATFORM_EXPORT void setFetchRedirectMode(FetchRedirectMode);
- // The LoFi state which determines whether to request a Lo-Fi version of the
- // resource.
- BLINK_PLATFORM_EXPORT LoFiState getLoFiState() const;
- BLINK_PLATFORM_EXPORT void setLoFiState(LoFiState);
+ // The PreviewsState which determines whether to request a Preview version of
+ // the resource. The PreviewsState is a bitmask of potentially several
+ // Previews optimizations.
+ BLINK_PLATFORM_EXPORT PreviewsState getPreviewsState() const;
+ BLINK_PLATFORM_EXPORT void setPreviewsState(PreviewsState);
// Extra data associated with the underlying resource request. Resource
// requests can be copied. If non-null, each copy of a resource requests
« no previous file with comments | « third_party/WebKit/Source/platform/network/ResourceRequest.cpp ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698